SegmentMetaError

Enum SegmentMetaError 

pub enum SegmentMetaError {
    UnsupportedFormat {
        format: FileFormat,
    },
    TooShort {
        path: String,
    },
    InvalidMagic {
        path: String,
    },
    ParquetRead {
        path: String,
        source: ParquetError,
        backtrace: Backtrace,
    },
    ArrowRead {
        path: String,
        source: ArrowError,
        backtrace: Backtrace,
    },
    TimeColumn {
        path: String,
        source: TimeColumnError,
    },
    ParquetStatsShape {
        path: String,
        column: String,
        detail: String,
    },
    ParquetStatsMissing {
        path: String,
        column: String,
    },
    LogicalSchemaInvalid {
        path: String,
        source: LogicalSchemaError,
    },
}
Errors that can occur while validating or decoding segment metadata.

This enum intentionally contains no storage backend errors. IO-related errors should be wrapped at the IO boundary (for example, in transaction_log::segments::SegmentError).

Variants



UnsupportedFormat

File format is not supported for v0.1.

Fields

format: FileFormat

The offending file format.



TooShort

The file is too short to be a valid Parquet file.

Fields

path: String

The path to the file that was too short.



InvalidMagic

Magic bytes at the start / end of file don’t match the Parquet spec.

Fields

path: String

The path to the file with invalid magic bytes.



ParquetRead

Parquet reader / metadata failure.

Fields

path: String

The path to the file that caused the Parquet read failure.

source: ParquetError

Underlying parquet error that caused this failure.

backtrace: Backtrace

Diagnostic backtrace for this error.



ArrowRead

Arrow decode failure while reading Parquet data.

Fields

path: String

The path to the file that caused the Arrow read failure.

source: ArrowError

Underlying Arrow error that caused this failure.

backtrace: Backtrace

Diagnostic backtrace for this error.



TimeColumn

Time column validation or metadata error.

Fields

path: String

The path to the segment file with a time column error.

source: TimeColumnError

The underlying time column error.



ParquetStatsShape

Statistics exist but are not well-shaped (wrong length / unexpected type).

Fields

path: String

The path to the file with malformed Parquet statistics.

column: String

The column whose statistics are malformed.

detail: String

Details about how the statistics are malformed.



ParquetStatsMissing

No usable statistics for the time column; v0.1 may fall back to a scan.

Fields

path: String

The path to the file missing statistics for the column.

column: String

The column missing statistics.



LogicalSchemaInvalid

Failed to derive a valid LogicalSchema from the Parquet file.

Fields

path: String

The path to the file without a valid LogicalSchema.

source: LogicalSchemaError

Underlying logical schema error that triggered this failure.