pub enum TableMetaSchemaError {
MissingCanonicalSchema,
Convert {
source: SchemaConvertError,
},
}Expand description
Errors encountered while retrieving or converting a table’s logical schema.
Variants
MissingCanonicalSchema
The table metadata has not yet recorded a canonical logical schema.
Convert
Failed to convert the logical schema to Arrow types.
Fields

source: SchemaConvertErrorUnderlying conversion error.