pub enum StorageError {
NotFound {
path: String,
source: BackendError,
backtrace: Backtrace,
},
AlreadyExists {
path: String,
source: BackendError,
backtrace: Backtrace,
},
OtherIo {
path: String,
source: BackendError,
backtrace: Backtrace,
},
AlreadyExistsNoSource {
path: String,
backtrace: Backtrace,
},
}Expand description
Errors that can occur during storage operations.
Variants
NotFound
The specified path was not found.
Fields

source: BackendErrorUnderlying backend error that caused the failure.
AlreadyExists
The specified path already exists when creation was requested with create-new semantics.
Fields

source: BackendErrorUnderlying backend error that indicates the existing resource.
OtherIo
An I/O error occurred on the local filesystem.
Fields

source: BackendErrorUnderlying backend I/O error with platform-specific details.
AlreadyExistsNoSource
The specified path already exists when creation was requested with create-new semantics.