pub enum CommitError {
Conflict {
expected: u64,
found: u64,
backtrace: Backtrace,
},
Storage {
source: StorageError,
},
CorruptState {
msg: String,
backtrace: Backtrace,
},
}Expand description
Errors that can occur while reading or writing the commit log.
Variants
Conflict
The caller’s expected_version does not match the CURRENT pointer.
Fields
Storage
Underlying storage error while working with the log or CURRENT file.
Backtraces are delegated to the inner StorageError.
Fields

source: StorageErrorUnderlying storage error returned by the storage backend.
CorruptState
The log or CURRENT file is in an unexpected / malformed state.