pub enum SchemaCompatibilityError {
MissingTableSchema,
MissingColumn {
column: String,
},
ExtraColumn {
column: String,
},
TypeMismatch {
column: String,
table_type: LogicalDataType,
segment_type: LogicalDataType,
},
TimeIndexTypeMismatch {
column: String,
table_type: LogicalDataType,
segment_type: LogicalDataType,
},
LogicalSchema {
source: LogicalSchemaError,
},
}Expand description
Errors raised when a segment’s schema is not compatible with the table.
Variants
MissingTableSchema
The table does not yet have a canonical logical schema.
Many call sites (like append) may choose to not use this and instead adopt the first segment’s schema, but we keep the error available for operations that require a fixed schema.
MissingColumn
The segment is missing a column that exists in the table schema.
ExtraColumn
The segment has an extra column that does not exist in the table schema.
TypeMismatch
Column exists in both schemas, but the logical type / nullability differ.
Fields
table_type: LogicalDataTypeThe type in the table schema.
segment_type: LogicalDataTypeThe type in the segment schema.
TimeIndexTypeMismatch
Specialised version of TypeMismatch for the time index column.
Fields
table_type: LogicalDataTypeThe type in the table schema.
segment_type: LogicalDataTypeThe type in the segment schema.
LogicalSchema
Logical schema construction or validation failed.
Fields
source: LogicalSchemaErrorThe underlying logical schema error.